rio_api 0.8.6

Unmaintained crate, use oxrdf
docs.rs failed to build rio_api-0.8.6
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: rio_api-0.8.5

Rio

actions status

Warning: Rio is unmaintained. Please use instead oxrdfio or the more specific crates oxttl and oxrdfxml.

Rio is a low level library which provides conformant and fast parsers and formatters for RDF related file formats.

These libraries are going to be replaced by the oxttl and oxrdfxml libraries.

It currently provides N-Triples, N-Quads, Turtle, TriG and RDF/XML parsers and formatters.

It is split into multiple crates:

There is also the rio_testsuite crate that is used for testing Rio parsers against the W3C RDF tests to ensure their conformance. It provides both an executable for building implementation reports and integration test to quickly ensure that the parsers stay conformant. It is not designed to be used outside of Rio.

License

Copyright 2019-2021 The Rio developers.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.